
A quoi ça sert ?
================

Ce programme sert à récupérer les adresses email des députés de l'assemblée nationale française.

Il permet de sélectionner les adresses email à partir :

* du nom d'un parti,
* du nom d'une région,
* du nom d'un département.

Les données sont récupérées à partir des données du site de l'assemblée nationnale.

Comment l'installer 
===================


Licence d'utilisation
=====================


Lien vers la doc
================
